@@ -1,27 +1,3 @@
-# Author: Johan Hanssen Seferidis
-# License: MIT
-# The MIT License (MIT)
-
-# Copyright (c) 2018 Johan Hanssen Seferidis
-
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-
 import re
 import sys
 import struct
@@ -68,7 +44,7 @@ OPCODE_PONG         = 0xA
 
 # -------------------------------- API ---------------------------------
 
-class API():
+class API(TCPServer):
 
     def run_forever(self):
         try:
@@ -108,9 +84,9 @@ class API():
 
 # ------------------------- Implementation -----------------------------
 
-class WebsocketServer(ThreadingMixIn, TCPServer, API):
+class WebsocketServer(ThreadingMixIn, API):
     """
-	A websocket server waiting for clients to connect.
+    A websocket server waiting for clients to connect.
 
     Args:
         port(int): Port to bind to
@@ -209,7 +185,7 @@ class WebSocketHandler(StreamRequestHandler):
     def read_next_message(self):
         try:
             b1, b2 = self.read_bytes(2)
-        except ValueError as e:
+        except ValueError:
             b1, b2 = 0, 0
 
         fin    = b1 & FIN
@@ -309,7 +285,6 @@ class WebSocketHandler(StreamRequestHandler):
 
         else:
             raise Exception("Message is too big. Consider breaking it into chunks.")
-            return
 
         self.text_to_send.insert(0, header + payload)
         if not self.sendding_text: 
@@ -321,7 +296,7 @@ class WebSocketHandler(StreamRequestHandler):
     def handshake(self):
         try:
             message = self.request.recv(1024 * 16).decode().strip()
-        except Exception as e:
+        except Exception:
             self.keep_alive = False
             return
         upgrade = re.search('\nupgrade[\s]*:[\s]*websocket', message.lower())
